pub struct PositionGrid(/* private fields */);Expand description
A grid-aligned position used for chunk look-ups.
A PositionGrid stores the coordinates of a chunk in the world
grid. Each component is the index of the chunk in the X and Y
direction.
Implementations
Sourceimpl PositionGrid
impl PositionGrid
Sourcepub fn distance(&self, other: &PositionGrid) -> isize
pub fn distance(&self, other: &PositionGrid) -> isize
Calculates the Euclidean distance between two grid positions.
The distance is computed by converting both grid positions to
world coordinates and then using Position::distance.
Sourcepub fn to_position(&self) -> Position
pub fn to_position(&self) -> Position
Converts the grid coordinates to world coordinates.
Each component is multiplied by CHUNK_SIZE to obtain the
corresponding world position.